summaryrefslogtreecommitdiffstats
path: root/vm/Exception.h
diff options
context:
space:
mode:
authorDan Bornstein <danfuzz@android.com>2011-03-04 11:53:40 -0800
committerDan Bornstein <danfuzz@android.com>2011-03-04 11:54:28 -0800
commit0b8b293f228b3d341054bc1fad8a92d6e533b4dd (patch)
treed2c1e59dfbb0fe48c0c0d830ed7d0967553a7fe3 /vm/Exception.h
parent9807b4e9412a6ce6863688c84a36ce294028ff04 (diff)
downloadandroid_dalvik-0b8b293f228b3d341054bc1fad8a92d6e533b4dd.tar.gz
android_dalvik-0b8b293f228b3d341054bc1fad8a92d6e533b4dd.tar.bz2
android_dalvik-0b8b293f228b3d341054bc1fad8a92d6e533b4dd.zip
Rename some of the exception functions.
Since the there is no longer a "ByClass" vs. not distinction, remove all the "ByClass"es. Bug: 3500987 Change-Id: I6bdaf5a31e8166b47c333dbbb394dc811f321c5d
Diffstat (limited to 'vm/Exception.h')
-rw-r--r--vm/Exception.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/vm/Exception.h b/vm/Exception.h
index d447591fe..2653e7629 100644
--- a/vm/Exception.h
+++ b/vm/Exception.h
@@ -38,51 +38,51 @@
* the initial class and then we can't find NoClassDefFoundError. We have
* to handle this case.
*/
-void dvmThrowChainedExceptionByClass(ClassObject* exceptionClass,
+void dvmThrowChainedException(ClassObject* exceptionClass,
const char* msg, Object* cause);
-INLINE void dvmThrowExceptionByClass(ClassObject* exceptionClass,
+INLINE void dvmThrowException(ClassObject* exceptionClass,
const char* msg)
{
- dvmThrowChainedExceptionByClass(exceptionClass, msg, NULL);
+ dvmThrowChainedException(exceptionClass, msg, NULL);
}
/*
* Like dvmThrowExceptionByClass, but takes printf-style args for the message.
*/
-void dvmThrowExceptionFmtByClassV(ClassObject* exceptionClass,
+void dvmThrowExceptionFmtV(ClassObject* exceptionClass,
const char* fmt, va_list args);
-void dvmThrowExceptionFmtByClass(ClassObject* exceptionClass,
+void dvmThrowExceptionFmt(ClassObject* exceptionClass,
const char* fmt, ...)
#if defined(__GNUC__)
__attribute__ ((format(printf, 2, 3)))
#endif
;
-INLINE void dvmThrowExceptionFmtByClass(ClassObject* exceptionClass,
+INLINE void dvmThrowExceptionFmt(ClassObject* exceptionClass,
const char* fmt, ...)
{
va_list args;
va_start(args, fmt);
- dvmThrowExceptionFmtByClassV(exceptionClass, fmt, args);
+ dvmThrowExceptionFmtV(exceptionClass, fmt, args);
va_end(args);
}
/*
* Like dvmThrowChainedExceptionByClass, but take a class object
* instead of a name and turn the given message into the
* human-readable form for a descriptor.
*/
-void dvmThrowChainedExceptionByClassWithClassMessage(
+void dvmThrowChainedExceptionWithClassMessage(
ClassObject* exceptionClass, const char* messageDescriptor,
Object* cause);
/*
* Like dvmThrowExceptionByClass, but take a class object instead of a name
* and turn the given message into the human-readable form for a descriptor.
*/
-INLINE void dvmThrowExceptionByClassWithClassMessage(
+INLINE void dvmThrowExceptionWithClassMessage(
ClassObject* exceptionClass, const char* messageDescriptor)
{
- dvmThrowChainedExceptionByClassWithClassMessage(exceptionClass,
+ dvmThrowChainedExceptionWithClassMessage(exceptionClass,
messageDescriptor, NULL);
}
@@ -38,51 +38,51 @@
}
/*
- * Like dvmThrowExceptionByClass, but takes printf-style args for the message.
+ * Like dvmThrowException, but takes printf-style args for the message.
*/
@@ -38,51 +38,51 @@
}
/*
- * Like dvmThrowChainedExceptionByClass, but take a class object
+ * Like dvmThrowChainedException, but take a class object
* instead of a name and turn the given message into the
* human-readable form for a descriptor.
@@ -38,51 +38,51 @@
Object* cause);
/*
- * Like dvmThrowExceptionByClass, but take a class object instead of a name
+ * Like dvmThrowException, but take a class object instead of a name
* and turn the given message into the human-readable form for a descriptor.
*/